Thawtime Havoc in Gothenburg Gothenburg, Sweden March 13th 2004 13 players Sten Düring Little Sister Description: This deck is actually not my own. I forgot to bring a deck to a tournament and borrowed this one. The primary creator is my little sister, Keiko Düring, and after that the deck has been heavily modified by her boyfriend, Max Widen, Beatrice Düring, my wife, and myself. Bleed, rush, beat the crap out of anything that stands in the way and pray that you don't encounter aggravated damage. The deck has a surprisingly powerful bloat-engine as well - something that is much needed as it intercepts very little and bounces not at all. Crypt (12 cards, min=16, max=31, avg=6.08) ------------------------------------------ 2x Jacko 8 CEL POT PRE obt Brujah antitribu:2 2x Theo Bell 7 POT cel dom pre Brujah:2 2x Sela 6 POT PRE cel obt bishop Brujah antitribu:2 2x Jimmy Dunn 4 CEL POT for Pander:2 1x Antonio Veradas 8 CEL POT PRE obf bishop Brujah antitribu:3 1x Miguel Santo Domingo 7 POT PRE cel for Brujah antitribu:3 1x Volker, The Puppet Prince 5 CEL pot prince Brujah:2 1x Jacob Bragg 3 cel pot Brujah antitribu:2 Library (90 cards) Master (18) 1x Amusement Park Hunting Ground 1x Archon Investigation 5x Blood Doll 2x Celerity 2x Direct Intervention 1x Gang Territory 2x Guardian Angel 1x KRCG News Radio 1x London Evening Star, Tabloid Newspaper 1x Powerbase: Montreal 1x Waste Management Operation Action (8) 6x Bum's Rush 1x Entrancement 1x Rampage Equipment (2) 1x Sport Bike 1x Sword of Judgment Action Modifier (5) 5x Iron Glare Reaction (7) 7x Wake with Evening's Freshness Combat (50) 6x Blur 3x Decapitate 3x Disarm 5x Flash 5x Immortal Grapple 4x Pursuit 5x Sideslip 6x Taste of Vitae 1x Thrown Gate 8x Torn Signpost 4x Undead Strength